==> ejc-probuilddiary-impl-3.0.0-20220916.100920-7-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonEquipmentEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-设备进场情况（设备管理员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_equipment")
public class PersonEquipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="lease_num")
    private BigDecimal leaseNum; // 租赁次数
    @TableField(value="purchase_num")
    private BigDecimal purchaseNum; // 采购次数
    @TableField(value="equipment_memo")
    private String equipmentMemo; // 工作描述
    
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public BigDecimal getLeaseNum() {
        return leaseNum;
    }

    public void setLeaseNum(BigDecimal leaseNum) {
        this.leaseNum = leaseNum;
    }
    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public String getEquipmentMemo() {
        return equipmentMemo;
    }

    public void setEquipmentMemo(String equipmentMemo) {
        this.equipmentMemo = equipmentMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20220919.070702-9-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonEquipmentEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-设备进场情况（设备管理员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_equipment")
public class PersonEquipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="lease_num")
    private BigDecimal leaseNum; // 租赁次数
    @TableField(value="purchase_num")
    private BigDecimal purchaseNum; // 采购次数
    @TableField(value="equipment_memo")
    private String equipmentMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型


    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public BigDecimal getLeaseNum() {
        return leaseNum;
    }

    public void setLeaseNum(BigDecimal leaseNum) {
        this.leaseNum = leaseNum;
    }
    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public String getEquipmentMemo() {
        return equipmentMemo;
    }

    public void setEquipmentMemo(String equipmentMemo) {
        this.equipmentMemo = equipmentMemo;
    }
    
}
